﻿using MapsterMapper;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Push.Share.Dtos;
using Push.Share.Dtos.FWMessage;
using Push.YiBin.Dtos;
using XF.Domain.Filters;
using XF.Domain.Repository;

namespace Push.YiBin.Host.Controllers
{
    public class PushMessageController : OriginController
    {
        #region 注入

        private readonly IRepository<Message> _messageRepository;
        private readonly IMapper _mapper;
        private readonly IPushDomainService _pushDomainService;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="messageRepository"></param>
        /// <param name="mapper"></param>
        /// <param name="pushDomainService"></param>
        public PushMessageController(IRepository<Message> messageRepository, IMapper mapper, IPushDomainService pushDomainService)
        {
            _messageRepository = messageRepository;
            _mapper = mapper;
            _pushDomainService = pushDomainService;
        }

        #endregion

        /// <summary>
        /// 新增代发短信
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost("addwaitmsg")]
        [AllowAnonymous]
        public async Task<Reponse> AddWaitMessage([FromBody] WaitMessageDto dto)
        {
            return await _pushDomainService.AddWaitMessage(_mapper.Map<WaitMessage>(dto), HttpContext.RequestAborted);
        }


        #region 新增

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPut("add")]
        [AllowAnonymous]
        public async Task AddMessage([FromBody] MessageDto dto)
        {
            await _pushDomainService.PushAsync(dto, HttpContext.RequestAborted);
        }

        #endregion

        #region 查询短信剩余数量

        /// <summary>
        /// 查询短信剩余数量
        /// </summary>
        /// <returns></returns>
        [HttpGet("query")]
        public async Task<string> GetAccountNum()
        {
            return await _pushDomainService.GetAccountNum();
        }

        #endregion

        #region 短信发送状态回调接口

        /// <summary>
        /// 短信发送状态回调接口
        /// </summary>
        /// <param name="receiveMessageDto"></param>
        /// <returns></returns>
        [HttpPost("receiveobtain")]
        [AllowAnonymous]
        public OpenResponse ReceiveObtain([FromForm] ReceiveMessageDto receiveMessageDto)
        {
            var result = _pushDomainService.ReceiveObtain(receiveMessageDto).GetAwaiter().GetResult();

            return OpenResponse.Ok(result);
        }

        #endregion

        #region 短信接收

        /// <summary>
        /// 短信接收
        /// </summary>
        /// <param name="receiveMessageDto"></param>
        /// <returns></returns>
        [HttpPost("receivesms")]
        [AllowAnonymous]
        public OpenResponse ReceiveSms([FromForm] ReceiveMessageDto receiveMessageDto)
        {
            var result = _pushDomainService.ReceiveSms(receiveMessageDto).GetAwaiter().GetResult();

            return OpenResponse.Ok(result);
        }

        #endregion
    }
}
