﻿using Mapster;
using Push.YiBin.Application;
using Push.YiBin.Extensions;
using Serilog;
using XF.Domain.Dependency;
using XF.Domain.Filters;
using XF.EasyCaching;
using XF.Utility.MQ;

namespace Push.YiBin.Host;

internal static class StartupExtensions
{
    const string CorsOrigins = "CorsOrigins";

    internal static WebApplication ConfigureServices(this WebApplicationBuilder builder)
    {
        var services = builder.Services;
        var configuration = builder.Configuration;

        services.AddHttpContextAccessor();

#if DEBUG
        builder.WebHost.UseUrls("http://*:50108");
#endif

        services.AddHttpClient();

        services.Configure<ChannelConfiguration>(d => configuration.GetSection(nameof(ChannelConfiguration)).Bind(d));

        // services.Configure<ChannelConfiguration>(d => configuration.GetSection(nameof(ChannelConfiguration)).Bind(d));

        // Add services to the container.
        services
            .BatchInjectServices()
            .RegisterRepository()
            .AddApplication()
            ;

        ////Authentication
        //services.RegisterAuthentication(configuration);

        services.AddControllers(options =>
        {
            options.Filters.Add<UnifyResponseFilter>();
            options.Filters.Add<UserFriendlyExceptionFilter>();
        })
            ;

        // Learn more about configuring Swagger/OpenAPI at https://aka.ms/aspnetcore/swashbuckle
        services.AddEndpointsApiExplorer();

        //swagger
        services.RegisterSwagger();

        /* CORS */
        services.RegisterCors(configuration, CorsOrigins);

        //mapster
        services.RegisterMapper();

        //mediatr
        services.AddMediatR(d => { d.RegisterServicesFromAssembly(typeof(ApplicationStartupExtensions).Assembly); });

        //sqlsugar
        services.AddSqlSugar(configuration);

        //关闭TS时间
        AppContext.SetSwitch("Npgsql.EnableLegacyTimestampBehavior", true);
        AppContext.SetSwitch("Npgsql.DisableDateTimeInfinityConversions", true);

        //cache
        services.AddCache(d =>
        {
            var cacheConfig = configuration.GetSection("Cache").Get<CacheOptions>();
            cacheConfig.Adapt(d);
            d.Prefix = "Push";
            d.TopicName = "push-topic";
        });


        //mq
        services.AddMq(configuration);

        services.RegisterJob();

        return builder.Build();
    }

    internal static WebApplication ConfigurePipelines(this WebApplication app)
    {
        app.UseSerilogRequestLogging();

        // Configure the HTTP request pipeline.
        var swaggerEnable = app.Configuration.GetSection("Swagger").Get<bool>();
        if (swaggerEnable)
        {
            app.UseSwagger();
            app.UseSwaggerUI();
        }

        app.UseCors(CorsOrigins);

        app.UseAuthentication();
        app.UseAuthorization();

        app.MapControllers()
            .RequireAuthorization();
        //app.MapSubscribeHandler();

        return app;
    }
}