﻿using Microsoft.AspNetCore.Http;
using System.Net.Http.Headers;
using System.Text;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Push.YiBin
{
    public class BaseHttpInvoker : IHttpInvoker, IScopeDependency
    {
        private readonly IHttpClientFactory _httpClientFactory;

        public BaseHttpInvoker(IHttpClientFactory httpClientFactory)
        {
            _httpClientFactory = httpClientFactory;
        }

        public async Task<TResponse?> RequestStringContentAsync<TResponse>(string url, string httpMethod, string? stringContent = null,
     Action<HttpClient>? setHttpClient = null, CancellationToken cancellationToken = default)
        {
            var httpClient = _httpClientFactory.CreateClient();

            if (setHttpClient != null)
                setHttpClient.Invoke(httpClient);

            var rsp = string.Empty;
            if (HttpMethods.IsGet(httpMethod))
            {
                rsp = await httpClient.GetStringAsync(url, cancellationToken);
            }
            else if (HttpMethods.IsPost(httpMethod))
            {
                using var responseMessage = await httpClient.PostAsync(url, new StringContent(stringContent, Encoding.UTF8, new MediaTypeWithQualityHeaderValue("application/json")),
                    cancellationToken);
                responseMessage.EnsureSuccessStatusCode();
                using var responseContent = responseMessage.Content;
                rsp = await responseContent.ReadAsStringAsync(cancellationToken);
            }
            else
            {
                throw new UserFriendlyException("暂不支持该请求方式");
            }

            return System.Text.Json.JsonSerializer.Deserialize<TResponse>(rsp);
        }
    }
}
