﻿using Microsoft.Extensions.DependencyInjection;
using XF.Domain.Dependency;
using XF.Domain.Exceptions;

namespace Push.YiBin
{
    public class FwClient : ISingletonDependency, ISelfDependency
    {
        private readonly IServiceScopeFactory _scopeFactory;

        /// <summary>
        /// 
        /// </summary>
        /// <param name="scopeFactory"></param>
        public FwClient(IServiceScopeFactory scopeFactory)
        {
            _scopeFactory = scopeFactory;
        }

        /// <summary>
        /// 请求，不带token
        /// </summary>
        /// <typeparam name="TResponse"></typeparam>
        /// <param name="url"></param>
        /// <param name="httpMethod"></param>
        /// <param name="stringContent"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        public async Task<TResponse?> RequestNoTokenAsync<TResponse>(string url, string httpMethod, string? stringContent = null, CancellationToken cancellationToken = default)
        {
            using var scope = _scopeFactory.CreateScope();
            var provider = scope.ServiceProvider;
            var channelconfigManager = provider.GetRequiredService<IChannelConfigurationManager>();
            var httpInvoker = provider.GetRequiredService<IHttpInvoker>();

            var configHotlineClient = channelconfigManager.GetConfigurationHotlineAddressUrl();
            if (!configHotlineClient.EndsWith('/'))
                configHotlineClient += "/";
            var postUrl = configHotlineClient + url;
            return await httpInvoker.RequestStringContentAsync<TResponse>(postUrl, httpMethod, stringContent,
                d => d.SetHttpClient(configHotlineClient), cancellationToken);
        }
    }

    public static class HttpClientExtensions
    {
        public static HttpClient SetHttpClient(this HttpClient httpClient, string baseAddress) =>
          httpClient.SetBaseAddress(baseAddress);

        public static HttpClient SetBaseAddress(this HttpClient httpClient, string baseAddress)
        {
            if (string.IsNullOrEmpty(baseAddress))
                throw new UserFriendlyException("无效 base address");
            httpClient.BaseAddress = new Uri(baseAddress);
            return httpClient;
        }
    }
}
