﻿using Push.Share.Enums;

namespace Push.YiBin
{
    /// <summary>
    /// 推送消息
    /// </summary>
    public class Message : CreationEntity
    {
        /// <summary>
        /// 业务类型（区分从哪个平台来的短信数据）
        /// </summary>
        [SugarColumn(ColumnDescription = "业务类型（区分从哪个平台来的短信数据）")]
        public string ClientId { get; set; }
        
        /// <summary>
        /// 外部业务唯一编号
        /// </summary>
        [SugarColumn(ColumnDescription = "外部业务唯一编号")]
        public string? ExternalId { get; set; }

        /// <summary>
        /// 业务系统短信ID
        /// </summary>
        [SugarColumn(ColumnDescription = "业务系统短信ID")]
        public int WaitSendId { get; set; } = 0;

        /// <summary>
        /// 推送状态
        /// </summary>
        [SugarColumn(ColumnDescription = "推送状态")]
        public EPushStatus Status { get; set; } = EPushStatus.Pushing;

        /// <summary>
        /// 短信内容
        /// </summary>
        [SugarColumn(ColumnDescription = "短信内容")]
        public string Content { get; set; }

        /// <summary>
        /// 备注
        /// </summary>
        [SugarColumn(ColumnDescription = "备注", ColumnDataType = "varchar(500)", IsNullable = true)]
        public string? Remark { get; set; }

        /// <summary>
        /// 接收姓名
        /// </summary>
        [SugarColumn(ColumnDescription = "接收姓名")]
        public string Name { get; set; }

        /// <summary>
        /// 接收手机号码
        /// </summary>
        [SugarColumn(ColumnDescription = "接收手机号码")]
        public string TelNumber { get; set; }

        /// <summary>
        /// 短信中心待发送ID
        /// </summary>
        [SugarColumn(ColumnDescription = "短信中心待发送ID", ColumnDataType = "varchar(20)", IsNullable = true)]
        public string? SmsWaitSendingId { get; set; }

        /// <summary>
        /// 短信中心已发送ID
        /// </summary>
        [SugarColumn(ColumnDescription = "短信中心已发送ID", ColumnDataType = "varchar(20)", IsNullable = true)]
        public string? SmsSendingCompletedId { get; set; }

        /// <summary>
        /// 发送短信使用的数量
        /// </summary>
        [SugarColumn(ColumnDescription = "发送短信使用的数量", IsNullable = true)]
        public int? MsgCount { get; set; }

        /// <summary>
        /// 短信发送状态
        /// </summary>
        [SugarColumn(ColumnDescription = "短信发送状态")]
        public ESendState SendState { get; set; }

        /// <summary>
        /// 发送时间
        /// </summary>
        [SugarColumn(ColumnDescription = "发送时间", IsNullable = true)]
        public DateTime? SendTime { get; set; }

        /// <summary>
        /// 短信回复是否回复
        /// </summary>   
        [SugarColumn(ColumnDescription = "短信回复是否回复")]
        public bool IsSmsReply { get; set; }

        /// <summary>
        /// 短信回复内容
        /// </summary>   
        [SugarColumn(ColumnDescription = "短信回复内容", ColumnDataType = "varchar(200)", IsNullable = true)]
        public string? SmsReplyContent { get; set; }

        /// <summary>
        /// 短信回复时间
        /// </summary>
        [SugarColumn(ColumnDescription = "短信回复时间", IsNullable = true)]
        public DateTime? SmsReplyTime { get; set; }

        /// <summary>
        /// 发送失败原因等
        /// </summary>
        [SugarColumn(ColumnDescription = "发送失败原因等", ColumnDataType = "varchar(200)", IsNullable = true)]
        public string? Reason { get; set; }

        /// <summary>
        /// 读取服务名称
        /// </summary>
        [SugarColumn(ColumnDescription = "读取服务名称")]
        public string? ProcessingServices { get; set; }
    }
}
